@@ -9,7 +9,7 @@ from pipictureframe.picdb.DbObjects import Metadata
 
 
 def _version_1_to_2(db: Database):
-    session = db.get_session()
+    session = db._get_session()
     last_db_update = datetime.strptime(
         session.query(Metadata)
         .filter(Metadata.key == LAST_DB_UPDATE_KEY_STR)
